Merge "Fix passing --classpath-dir to dex2oat for split apks."
diff --git a/cmds/installd/dexopt.cpp b/cmds/installd/dexopt.cpp
index 7776764..0d89da4 100644
--- a/cmds/installd/dexopt.cpp
+++ b/cmds/installd/dexopt.cpp
@@ -362,14 +362,14 @@
         sprintf(profile_arg, "--profile-file-fd=%d", profile_fd);
     }
 
-    // Get the directory of the apk to pass as a base directory.
-    char base_dir[arraysize("--base-dir=") + PKG_PATH_MAX];
+    // Get the directory of the apk to pass as a base classpath directory.
+    char base_dir[arraysize("--classpath-dir=") + PKG_PATH_MAX];
     std::string apk_dir(input_file_name);
     unsigned long dir_index = apk_dir.rfind('/');
     bool has_base_dir = dir_index != std::string::npos;
     if (has_base_dir) {
         apk_dir = apk_dir.substr(0, dir_index);
-        sprintf(base_dir, "--base-dir=%s", apk_dir.c_str());
+        sprintf(base_dir, "--classpath-dir=%s", apk_dir.c_str());
     }